@@ -7,30 +7,28 @@ from xml.dom import minidom
 
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
-from django.shortcuts import render_to_response, redirect, render
-from django.template import RequestContext
+from django.shortcuts import redirect
 from django.views.generic import ListView, TemplateView, View
 
 from braces.views import LoginRequiredMixin
 
 from .forms import StringSearchForm, ImportOpmlFileForm
-from .models import Options, Group, Feed, Entry
-from .utils import poll_feed, build_context
+from .models import Group, Feed, Entry
+from .utils import build_context
 
 
 class NumbersUnread(LoginRequiredMixin, View):
     def get(self, request, *args, **kwargs):
         """Count numbers of unread entries, return in json object"""
-        context = {}
-        context['unread_total'] = Entry.objects.filter(read_flag=False).count()
+        context = {'unread_total': Entry.manager.num_unread()}
         groups = Group.objects.all()
         for group in groups:
-            num_unread = Entry.objects.filter(feed__group=group, read_flag=False).count()
+            num_unread = group.num_unread_entries()
             context['unread_group%s' % (group.id)] = num_unread
             context['unread_group_button%s' % (group.id)] = num_unread
         feeds = Feed.objects.all()
         for feed in feeds:
-            context['unread_feed%s' % (feed.id)] = Entry.objects.filter(feed=feed, read_flag=False).count()
+            context['unread_feed%s' % (feed.id)] = feed.num_unread_entries()
         return HttpResponse(json.dumps(context), content_type='application/json')
 
 
